The 'any' and 'all' are modified to the 'mapped' concept, so move them last in 
the name.

No change in functionality.

Cc: Alex Thorlton <[email protected]>
Cc: Andy Lutomirski <[email protected]>
Cc: Borislav Petkov <[email protected]>
Cc: Brian Gerst <[email protected]>
Cc: Dan Williams <[email protected]>
Cc: Denys Vlasenko <[email protected]>
Cc: H. Peter Anvin <[email protected]>
Cc: Huang, Ying <[email protected]>
Cc: Josh Poimboeuf <[email protected]>
Cc: Juergen Gross <[email protected]>
Cc: Linus Torvalds <[email protected]>
Cc: Paul Jackson <[email protected]>
Cc: Peter Zijlstra <[email protected]>
Cc: Rafael J. Wysocki <[email protected]>
Cc: Tejun Heo <[email protected]>
Cc: Thomas Gleixner <[email protected]>
Cc: Wei Yang <[email protected]>
Cc: Yinghai Lu <[email protected]>
Cc: [email protected]
Signed-off-by: Ingo Molnar <[email protected]>
---
 arch/x86/include/asm/e820/api.h |  4 ++--
 arch/x86/include/asm/gart.h     |  2 +-
 arch/x86/kernel/aperture_64.c   |  2 +-
 arch/x86/kernel/e820.c          |  6 +++---
 arch/x86/kernel/setup.c         |  2 +-
 arch/x86/kernel/tboot.c         |  2 +-
 arch/x86/mm/init_64.c           | 12 ++++++------
 arch/x86/pci/mmconfig-shared.c  |  4 ++--
 arch/x86/platform/efi/quirks.c  |  2 +-
 9 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/arch/x86/include/asm/e820/api.h b/arch/x86/include/asm/e820/api.h
index 9f3917805fc6..3ba95d462bbc 100644
--- a/arch/x86/include/asm/e820/api.h
+++ b/arch/x86/include/asm/e820/api.h
@@ -8,8 +8,8 @@ extern struct e820_table *e820_table_firmware;
 
 extern unsigned long pci_mem_start;
 
-extern int  e820_any_mapped(u64 start, u64 end, unsigned type);
-extern int  e820_all_mapped(u64 start, u64 end, unsigned type);
+extern int  e820__mapped_any(u64 start, u64 end, unsigned type);
+extern int  e820__mapped_all(u64 start, u64 end, unsigned type);
 extern void e820_add_region(u64 start, u64 size, int type);
 extern void e820_print_map(char *who);
 extern int  e820__update_table(struct e820_entry *biosmap, int max_nr_map, u32 
*pnr_map);
diff --git a/arch/x86/include/asm/gart.h b/arch/x86/include/asm/gart.h
index e26a5d7fc368..2a3ff2ac4686 100644
--- a/arch/x86/include/asm/gart.h
+++ b/arch/x86/include/asm/gart.h
@@ -97,7 +97,7 @@ static inline int aperture_valid(u64 aper_base, u32 
aper_size, u32 min_size)
                printk(KERN_INFO "Aperture beyond 4GB. Ignoring.\n");
                return 0;
        }
-       if (e820_any_mapped(aper_base, aper_base + aper_size, E820_RAM)) {
+       if (e820__mapped_any(aper_base, aper_base + aper_size, E820_RAM)) {
                printk(KERN_INFO "Aperture pointing to e820 RAM. Ignoring.\n");
                return 0;
        }
diff --git a/arch/x86/kernel/aperture_64.c b/arch/x86/kernel/aperture_64.c
index e21d012c557b..d027858a306e 100644
--- a/arch/x86/kernel/aperture_64.c
+++ b/arch/x86/kernel/aperture_64.c
@@ -306,7 +306,7 @@ void __init early_gart_iommu_check(void)
                fix = 1;
 
        if (gart_fix_e820 && !fix && aper_enabled) {
-               if (e820_any_mapped(aper_base, aper_base + aper_size,
+               if (e820__mapped_any(aper_base, aper_base + aper_size,
                                    E820_RAM)) {
                        /* reserve it, so we can reuse it in second kernel */
                        pr_info("e820: reserve [mem %#010Lx-%#010Lx] for 
GART\n",
diff --git a/arch/x86/kernel/e820.c b/arch/x86/kernel/e820.c
index 0053c9f1f6e2..804acee76aca 100644
--- a/arch/x86/kernel/e820.c
+++ b/arch/x86/kernel/e820.c
@@ -68,7 +68,7 @@ EXPORT_SYMBOL(pci_mem_start);
  * This function checks if any part of the range <start,end> is mapped
  * with type.
  */
-int e820_any_mapped(u64 start, u64 end, unsigned type)
+int e820__mapped_any(u64 start, u64 end, unsigned type)
 {
        int i;
 
@@ -83,7 +83,7 @@ int e820_any_mapped(u64 start, u64 end, unsigned type)
        }
        return 0;
 }
-EXPORT_SYMBOL_GPL(e820_any_mapped);
+EXPORT_SYMBOL_GPL(e820__mapped_any);
 
 /*
  * This function checks if the entire <start,end> range is mapped with 'type'.
@@ -91,7 +91,7 @@ EXPORT_SYMBOL_GPL(e820_any_mapped);
  * Note: this function only works correctly once the E820 table is sorted and
  * not-overlapping (at least for the range specified), which is the case 
normally.
  */
-int __init e820_all_mapped(u64 start, u64 end, unsigned type)
+int __init e820__mapped_all(u64 start, u64 end, unsigned type)
 {
        int i;
 
diff --git a/arch/x86/kernel/setup.c b/arch/x86/kernel/setup.c
index e8ec0c693a77..5ea90a2b3709 100644
--- a/arch/x86/kernel/setup.c
+++ b/arch/x86/kernel/setup.c
@@ -756,7 +756,7 @@ static void __init e820_add_kernel_range(void)
         * exclude kernel range. If we really are running on top non-RAM,
         * we will crash later anyways.
         */
-       if (e820_all_mapped(start, start + size, E820_RAM))
+       if (e820__mapped_all(start, start + size, E820_RAM))
                return;
 
        pr_warn(".text .data .bss are not marked as E820_RAM!\n");
diff --git a/arch/x86/kernel/tboot.c b/arch/x86/kernel/tboot.c
index f7cba42d7807..0e2dc3831970 100644
--- a/arch/x86/kernel/tboot.c
+++ b/arch/x86/kernel/tboot.c
@@ -68,7 +68,7 @@ void __init tboot_probe(void)
         * also verify that it is mapped as we expect it before calling
         * set_fixmap(), to reduce chance of garbage value causing crash
         */
-       if (!e820_any_mapped(boot_params.tboot_addr,
+       if (!e820__mapped_any(boot_params.tboot_addr,
                             boot_params.tboot_addr, E820_RESERVED)) {
                pr_warning("non-0 tboot_addr but it is not of type 
E820_RESERVED\n");
                return;
diff --git a/arch/x86/mm/init_64.c b/arch/x86/mm/init_64.c
index ad7a477f3423..cfb119e4c4d1 100644
--- a/arch/x86/mm/init_64.c
+++ b/arch/x86/mm/init_64.c
@@ -337,9 +337,9 @@ phys_pte_init(pte_t *pte_page, unsigned long paddr, 
unsigned long paddr_end,
                paddr_next = (paddr & PAGE_MASK) + PAGE_SIZE;
                if (paddr >= paddr_end) {
                        if (!after_bootmem &&
-                           !e820_any_mapped(paddr & PAGE_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PAGE_MASK, paddr_next,
                                             E820_RAM) &&
-                           !e820_any_mapped(paddr & PAGE_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PAGE_MASK, paddr_next,
                                             E820_RESERVED_KERN))
                                set_pte(pte, __pte(0));
                        continue;
@@ -392,9 +392,9 @@ phys_pmd_init(pmd_t *pmd_page, unsigned long paddr, 
unsigned long paddr_end,
                paddr_next = (paddr & PMD_MASK) + PMD_SIZE;
                if (paddr >= paddr_end) {
                        if (!after_bootmem &&
-                           !e820_any_mapped(paddr & PMD_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PMD_MASK, paddr_next,
                                             E820_RAM) &&
-                           !e820_any_mapped(paddr & PMD_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PMD_MASK, paddr_next,
                                             E820_RESERVED_KERN))
                                set_pmd(pmd, __pmd(0));
                        continue;
@@ -478,9 +478,9 @@ phys_pud_init(pud_t *pud_page, unsigned long paddr, 
unsigned long paddr_end,
 
                if (paddr >= paddr_end) {
                        if (!after_bootmem &&
-                           !e820_any_mapped(paddr & PUD_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PUD_MASK, paddr_next,
                                             E820_RAM) &&
-                           !e820_any_mapped(paddr & PUD_MASK, paddr_next,
+                           !e820__mapped_any(paddr & PUD_MASK, paddr_next,
                                             E820_RESERVED_KERN))
                                set_pud(pud, __pud(0));
                        continue;
diff --git a/arch/x86/platform/efi/quirks.c b/arch/x86/platform/efi/quirks.c
index c6a14b11f496..d4acd1668d36 100644
--- a/arch/x86/platform/efi/quirks.c
+++ b/arch/x86/platform/efi/quirks.c
@@ -249,7 +249,7 @@ static bool can_free_region(u64 start, u64 size)
        if (start + size > __pa_symbol(_text) && start <= __pa_symbol(_end))
                return false;
 
-       if (!e820_all_mapped(start, start+size, E820_RAM))
+       if (!e820__mapped_all(start, start+size, E820_RAM))
                return false;
 
        return true;
diff --git a/arch/x86/pci/mmconfig-shared.c b/arch/x86/pci/mmconfig-shared.c
index 767199edef74..696b050bdc45 100644
--- a/arch/x86/pci/mmconfig-shared.c
+++ b/arch/x86/pci/mmconfig-shared.c
@@ -514,7 +514,7 @@ static int __ref pci_mmcfg_check_reserved(struct device 
*dev,
        }
 
        /*
         * e820_all_mapped() is marked as __init.
         * All entries from ACPI MCFG table have been checked at boot time.
         * For MCFG information constructed from hotpluggable host bridge's
         * _CBA method, just assume it's reserved.
@@ -525,7 +525,7 @@ static int __ref pci_mmcfg_check_reserved(struct device 
*dev,
        /* Don't try to do this check unless configuration
           type 1 is available. how about type 2 ?*/
        if (raw_pci_ops)
-               return is_mmconf_reserved(e820_all_mapped, cfg, dev, 1);
+               return is_mmconf_reserved(e820__mapped_all, cfg, dev, 1);
 
        return 0;
 }
@@ -514,7 +514,7 @@ static int __ref pci_mmcfg_check_reserved(struct device 
 
        /*
-        * e820_all_mapped() is marked as __init.
+        * e820__mapped_all() is marked as __init.
         * All entries from ACPI MCFG table have been checked at boot time.
         * For MCFG information constructed from hotpluggable host bridge's
-- 
2.7.4

Reply via email to